<?php

/**
 * @file
 * Drush integration for jQuery-viewport-checker.
 */

/**
 * Implements hook_drush_command().
 */
function viewportchecker_drush_command() {
  $items = [];

  // The key in the $items array is the name of the command.
  $items['viewportchecker:library'] = [
    'callback' => 'drush_viewportchecker_download',
    'description' => dt('Download and install the jQuery-viewport-checker library.'),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
    'aliases' => ['vpc-dl'],
  ];

  return $items;
}

/**
 * Command to download the jQuery-viewport-checker library.
 */
function _viewportchecker_download_file($url, $filename) {
  $curl = curl_init();
  curl_setopt($curl, CURLOPT_URL, $url);
  curl_setopt($curl, CURLOPT_HEADER, 0);
  curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
  $result = curl_exec($curl);
  if (!$result) {
    return FALSE;
  }
  curl_close($curl);

  $file = fopen($filename, "w+");
  if (!fwrite($file, $result)) {
    return FALSE;
  }
  fclose($file);

  return TRUE;
}

/**
 * Command to download the jQuery-viewport-checker library.
 */
function drush_viewportchecker_download() {
  $path = getcwd() . '/sites/all/libraries/jquery.viewportchecker';
  $dist_path = $path . '/dist';
  $src_path = $path . '/src';
  $lib_name_min = 'jquery.viewportchecker.min.js';
  $lib_name = 'jquery.viewportchecker.js';
  $vpc_download_uri_min = 'https://raw.githubusercontent.com/ivnish/viewport-checker/master/dist/jquery.viewportchecker.min.js';
  $vpc_download_uri = 'https://raw.githubusercontent.com/ivnish/viewport-checker/master/src/jquery.viewportchecker.js';

  // Create the path if it does not exist.
  if (!is_dir($path)) {
    drush_op('mkdir', $path);
    drush_print('Directory sites/all/libraries/jquery.viewportchecker was created');
  }

  // Download jQuery-viewport-checker library only if path is writable.
  if (is_writable($path)) {
    if (!is_dir($dist_path)) {
      drush_op('mkdir', $dist_path);
    }

    if (!is_dir($src_path)) {
      drush_op('mkdir', $src_path);
    }

    // Set the directory to the download location.
    chdir($dist_path);

    if (_viewportchecker_download_file($vpc_download_uri_min, $lib_name_min)) {
      drush_print('The library ' . $lib_name_min . ' was successfully downloaded!');
    }
    else {
      drush_print('Cant download the library ' . $lib_name_min);
    }

    chdir($src_path);

    if (_viewportchecker_download_file($vpc_download_uri, $lib_name)) {
      drush_print('The library ' . $lib_name . ' was successfully downloaded!');
    }
    else {
      drush_print('Cant download the library ' . $lib_name);
    }
  }
  else {
    drush_print(dt('Drush was unable to install the jQuery-viewport-checker library because @path is not writable.', ['@path' => $path]), 'warning');
  }

}
